==> react-native-deuna-library-0.3.0.tgz: package/src/components/VistaPreviaValoPagar.tsx <==
import React, { useEffect } from 'react';
('react-native-paper');
import { View, Text, StyleSheet, Pressable } from 'react-native';
import { useNavigation, useRoute } from '@react-navigation/native';
import { CuentaMin } from './CuentaMin';

import numerosregistrados from '../datos/numerosregistrados.json';
export const VistaPreviaValoPagar = () => {
  const navigate = useNavigation<any>();
  const [ValorPagar, setValorPagar] = React.useState<number>(0);
  const [datos, setDatos] = React.useState<any>({});
  const route = useRoute<any>();
  useEffect(() => {
    console.log(route.params);
    numerosregistrados.forEach((item: any) => {
      if (item.number === route.params.number) {
        setDatos(item);
      }
    });
    setValorPagar(route.params.valorPagar);
  }, [datos, route]);
  const accountbind = (account: string) => {
    const accountbin =
      account.substring(0, 4) + '*****' + account.substring(8, 11);
    return accountbin;
  };
  return (
    <View style={styles.containerVistaPrevia}>
      <Text style={styles.encabezados}>Para </Text>
      <View style={styles.contenedorSeccion}>
        <Text style={styles.nombre}>{datos.name}</Text>
        <Text>Parar DeUna! -{datos.number}</Text>
        {datos && datos.account ? (
          <Text>Cuenta de ahorros - {accountbind(datos.account)}</Text>
        ) : null}
      </View>
      <Text style={styles.encabezados}>Valor</Text>

      <View style={styles.contenedorSeccion}>
        <Text style={styles.ValorPagar}>${ValorPagar}</Text>
      </View>

      <Text style={styles.encabezados}>Desde</Text>
      {datos && datos.account ? (
        <CuentaMin numberAccount={accountbind(datos.account)} />
      ) : null}
      <Text style={styles.encabezados}>Descripcion</Text>

      {/*<TextInput
        style={styles.input}
        placeholder="¿Que estas pagando? (Opcional)"
        maxLength={40}
      />*/}
      <Pressable
        onPress={() =>
          navigate.navigate('ConfirmarTransaccion', {
            number: datos?.number,
            valorPagar: ValorPagar,
          })
        }
        style={styles.Btncontinuar}
      >
        <Text>Pagar</Text>
      </Pressable>
    </View>
  );
};

const styles = StyleSheet.create({
  input: {
    backgroundColor: '#FFFFFF',
    borderStyle: 'solid',
    borderColor: 'black',
    padding: 10,
  },
  Btncontinuar: {
    width: '100%',
    backgroundColor: '#FFDD00',
    padding: 15,
    marginTop: 35,
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
  },
  nombre: {
    fontSize: 19,
    fontWeight: 'bold',
    color: 'black',
  },
  containerVistaPrevia: {
    flex: 1,
    padding: 35,
    width: '100%',
    backgroundColor: '#FFFFFF',
    // CAMBIAR LA ALTURA LA 100% DE LA PANTALLA
    height: 650,
  },
  encabezados: {
    fontWeight: 'bold',
    fontSize: 16,
    paddingTop: 10,
    paddingBottom: 10,
  },
  contenedorSeccion: {
    padding: 8,
  },
  ValorPagar: {
    fontSize: 36,
    fontWeight: 'bold',
    color: 'black',
  },
});

==> react-native-deuna-library-0.5.11.tgz: package/src/components/VistaPreviaValoPagar.tsx <==
import React from 'react';
import { useEffect } from 'react';
import { View, Text, StyleSheet, Pressable } from 'react-native';
import { useNavigation, useRoute } from '@react-navigation/native';
import { CuentaMin } from './CuentaMin';

import numerosregistrados from '../datos/numerosregistrados.json';
export const VistaPreviaValoPagar = () => {
  const navigate = useNavigation<any>();
  const [ValorPagar, setValorPagar] = React.useState<number>(0);
  const [datos, setDatos] = React.useState<any>({});
  const route = useRoute<any>();
  useEffect(() => {
    console.log(route.params);
    numerosregistrados.forEach((item: any) => {
      if (item.number === route.params.number) {
        setDatos(item);
        
      }
    });
    console.log(datos);
    setValorPagar(route.params.valorPagar);
  }, [datos, route]);
  const accountbind = (account: string) => {
    const accountbin =
      account.substring(0, 4) + '*****' + account.substring(8, 11);
    return accountbin;
  };
  return (
    <View style={styles.containerVistaPrevia}>
      <View style={styles.encabezado}>
        <Text style={styles.textoEncabezado}>Confirma tu pago</Text>
      </View>
      <Text style={styles.encabezados}>Para </Text>
      <View style={styles.contenedorSeccion}>
        <Text style={styles.nombre}>{datos.name}</Text>
        <Text>Parar DeUna! -{datos.number}</Text>
        {datos && datos.account ? (
          <Text>Cuenta de ahorros - {accountbind(datos.account)}</Text>
        ) : null}
      </View>
      <Text style={styles.encabezados}>Valor</Text>

      <View style={styles.contenedorSeccion}>
        <Text style={styles.ValorPagar}>
          ${ValorPagar ? ValorPagar.toFixed(2) : 0.0}
        </Text>
      </View>

      <Text style={styles.encabezados}>Desde</Text>
      {datos && datos.account ? (
        <CuentaMin numberAccount={accountbind(datos.account)} />
      ) : null}
      <Text style={styles.encabezados}>Descripcion</Text>

      {/*<TextInput
        style={styles.input}
        placeholder="¿Que estas pagando? (Opcional)"
        maxLength={40}
      />*/}
      <Pressable
        onPress={() =>
          navigate.navigate('ConfirmarTransaccion', {
            number: datos?.number,
            valorPagar: ValorPagar,
          })
        }
        style={styles.Btncontinuar}
      >
        <Text>Pagar</Text>
      </Pressable>
    </View>
  );
};

const styles = StyleSheet.create({
  textoEncabezado: {
    fontWeight: 'bold',
    fontSize: 20,
  },
  encabezado: {
    width: '100%',
  },
  input: {
    backgroundColor: '#FFFFFF',
    borderStyle: 'solid',
    borderColor: 'black',
    padding: 10,
  },
  Btncontinuar: {
    width: '100%',
    backgroundColor: '#FFDD00',
    padding: 15,
    marginTop: 35,
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
  },
  nombre: {
    fontSize: 19,
    fontWeight: 'bold',
    color: 'black',
  },
  containerVistaPrevia: {
    flex: 1,
    padding: 35,
    width: '100%',
    backgroundColor: '#FFFFFF',
    // CAMBIAR LA ALTURA LA 100% DE LA PANTALLA
    height: 650,
  },
  encabezados: {
    fontWeight: 'bold',
    fontSize: 16,
    paddingTop: 10,
    paddingBottom: 10,
  },
  contenedorSeccion: {
    padding: 8,
  },
  ValorPagar: {
    fontSize: 36,
    fontWeight: 'bold',
    color: 'black',
  },
});
